- x
An object created with crossnma.
- median
A logical indicating whether to use the median
(default) or mean to measure relative treatment effects.
- backtransf
A logical indicating whether results should be
back transformed. If backtransf = TRUE, results for
sm = "OR" are presented as odds ratios rather than log
odds ratios, for example.
- seq
A vector of treatment names (character) representing
the order in which to display these treatments.
- low.colour
A string indicating the colour of low relative
treatment effects for the heat plot (e.g odds ratio of ~0.5)
- mid.colour
A string indicating the colour of null relative
treatment effects for the heat plot (e.g odds ratio of ~1.0).
- high.colour
A string indicating the colour of high relative
treatment effects for the heat plot (e.g odds ratio of ~2.0).
- cov1.value
The participant covariate value of cov1
for which to report the results. Must be specified for network
meta-regression and when individual participant dataset is used
in the analysis. For dichotomous covariates, a character of the
level (used in the data) should be indicated.
- cov2.value
The participant covariate value of cov2
for which to report the results. Must be specified for network
meta-regression and when individual participant dataset is used
in the analysis. For dichotomous covariates, a character of the
level (used in the data) should be indicated.
- cov3.value
The participant covariate value of cov3
for which to report the results. Must be specified for network
meta-regression and when individual participant dataset is used
in the analysis. For dichotomous covariates, a character of the
level (used in the data) should be indicated.
- size
The size of cell entries with the relative treatment
effect and 95% credible intervals.
- size.trt
The size of treatment names placed on the top and
left of the plot.
- size.axis
The size of labels on the top and left of the plot
- digits
The number of digits to be used when displaying the
results.
- exp
Deprecated argument (replaced by backtransf).
- ...
Additional arguments (ignored at the moment).