Learn R Programming

crossnma (version 1.3.0)

print.crossnma: Print results of cross-design & -format network meta-analysis or regression

Description

Print call used to create JAGS model for cross-design & -format network meta-analysis or regression

Usage

# S3 method for crossnma
print(x, backtransf = x$model$backtransf, digits = gs("digits"), ...)

Value

No return value (print function).

Arguments

x

An object of class crossnma.

backtransf

A logical indicating whether results should be back transformed. If backtransf = TRUE, results for sm = "OR" are presented as odds ratios rather than log odds ratios, for example.

digits

The number of significant digits printed.

...

Additional arguments.

See Also

crossnma

Examples

Run this code
if (FALSE) {
# We conduct a network meta-analysis assuming a random-effects
# model.
# The data comes from randomized-controlled trials and
# non-randomized studies (combined naively)
head(ipddata) # participant-level data
stddata # study-level data

# Create a JAGS model
mod <- crossnma.model(treat, id, relapse, n, design,
  prt.data = ipddata, std.data = stddata,
  reference = "A", trt.effect = "random", method.bias = "naive")

# Fit JAGS model
# (suppress warning 'Adaptation incomplete' due to n.adapt = 20)
fit <-
  suppressWarnings(crossnma(mod))
fit
}

Run the code above in your browser using DataLab